@@ -42,9 +42,11 @@ case "$1" in
 		case "$2" in
 			maemo5)
 				menubar_file=data/default/menubar.maemo5.xml
+				popup_file=data/default/popupmenu.maemo5.xml
 				;;
 			*)
 				menubar_file=data/default/menubar.xml
+				popup_file=data/default/popupmenu.maemo.xml
 				;;
 			esac;
 		;;
@@ -66,3 +68,7 @@ fi;
 if [ "$menubar_file" != "" ]; then
 	install -m 0644 $menubar_file $3/menubar.xml;
 fi;
+
+if [ "$popup_file" != "" ]; then
+	install -m 0644 $popup_file $3/popupmenu.xml;
+fi;
