@@ -20,9 +20,9 @@
 #include "FBReader.h"
 #include "FBReaderActions.h"
 
-BooksOrderAction::BooksOrderAction() : ModeDependentAction(FBReader::LIBRARY_MODE) {
+BooksOrderAction::BooksOrderAction(const std::string &actionId) : ModeDependentAction(FBReader::LIBRARY_MODE), myActionId(actionId) {
 }
 
 void BooksOrderAction::run() {
-	FBReader::Instance().showLibraryView();
+	FBReader::Instance().showLibraryView(myActionId);
 }
