@@ -285,28 +285,23 @@ bool FBReader::createBook(const std::string& fileName, shared_ptr<Book> &book) {
 class OpenBookRunnable : public ZLRunnable {
 
 public:
-	OpenBookRunnable(shared_ptr<Book> book) : myBook(book) {}
-	void run() { FBReader::Instance().openBookInternal(myBook); }
+	OpenBookRunnable(shared_ptr<Book> book, bool forceReload) : myBook(book), myForceReload(forceReload) {}
+	void run() { FBReader::Instance().openBookInternal(myBook, myForceReload); }
 
 private:
 	shared_ptr<Book> myBook;
+    bool myForceReload;
 };
 
-void FBReader::openBook(shared_ptr<Book> book) {
-	OpenBookRunnable runnable(book);
+void FBReader::openBook(shared_ptr<Book> book, bool forceReload) {
+	OpenBookRunnable runnable(book, forceReload);
 	ZLDialogManager::Instance().wait(ZLResourceKey("loadingBook"), runnable);
 	resetWindowCaption();
 	refreshWindow();
 }
 
-void FBReader::openBookInternal(shared_ptr<Book> book) {
+void FBReader::openBookInternal(shared_ptr<Book> book, bool forceReload) {
 	if (!book.isNull()) {
-		if ((!myModel.isNull()) && (book->filePath() == myModel->book()->filePath())) {
-			closeView();
-			refreshWindow();
-			return;
-		}
-
 		BookTextView &bookTextView = (BookTextView&)*myBookTextView;
 		ContentsView &contentsView = (ContentsView&)*myContentsView;
 		FootnoteView &footnoteView = (FootnoteView&)*myFootnoteView;
@@ -315,9 +310,15 @@ void FBReader::openBookInternal(shared_ptr<Book> book) {
 		bookTextView.setModel(0, 0);
 		bookTextView.setContentsModel(0);
 		contentsView.setModel(0);
-		myModel.reset();
-		myModel = new BookModel(book);
-		ZLTextHyphenator::Instance().load(book->language());
+
+		if ((myModel.isNull()) ||
+                (book->filePath() != myModel->book()->filePath()) ||
+				forceReload) {
+			myModel.reset();
+			myModel = new BookModel(book);
+			ZLTextHyphenator::Instance().load(book->language());
+		}
+
 		bookTextView.setModel(myModel->bookTextModel(), book);
 		bookTextView.setCaption(book->title());
 		bookTextView.setContentsModel(myModel->contentsModel());
