@@ -117,7 +117,7 @@ public:
 	void tryShowFootnoteView(const std::string &id, const std::string &type);
 	BookTextView &bookTextView() const;
 	void showBookTextView();
-	void openBook(shared_ptr<Book> book);
+	void openBook(shared_ptr<Book> book, bool forceReload = false);
 
 	void invalidateNetworkView();
 	void invalidateAccountDependents();
@@ -128,7 +128,7 @@ public:
 private:
 	shared_ptr<ProgramCollection> dictionaryCollection() const;
 
-	void openBookInternal(shared_ptr<Book> book);
+	void openBookInternal(shared_ptr<Book> book, bool forceReload);
 	friend class OpenBookRunnable;
 	void rebuildCollectionInternal();
 	friend class RebuildCollectionRunnable;
