@@ -136,8 +136,18 @@ ShowBookInfoAction::ShowBookInfoAction() : ModeDependentAction(FBReader::BOOK_TE
 void ShowBookInfoAction::run() {
 	FBReader &fbreader = FBReader::Instance();
 	shared_ptr<Book> book = fbreader.myModel->book();
+
+	std::string oldLanguage = book->language();
+	std::string oldEncoding = book->encoding();
+
 	if (BookInfoDialog(book).dialog().run()) {
-		fbreader.openBook(book);
+		bool forceReload = false;
+		if ((book->language() != oldLanguage) ||
+				(book->encoding() != oldEncoding)) {
+			forceReload = true;
+		}
+
+		fbreader.openBook(book, forceReload);
 		fbreader.refreshWindow();
 	}
 }
