@@ -40,6 +40,7 @@ XHTMLImageFinder::XHTMLImageFinder(OEBCoverReader &coverReader) : myCoverReader(
 }
 
 static const std::string IMG = "img";
+static const std::string SVG_IMAGE = "image";
 
 void XHTMLImageFinder::startElementHandler(const char *tag, const char **attributes) {
 	if (IMG == tag) {
@@ -49,6 +50,13 @@ void XHTMLImageFinder::startElementHandler(const char *tag, const char **attribu
 				new ZLFileImage("image/auto", myCoverReader.myPathPrefix + src, 0);
 			interrupt();
 		}
+	} else if (SVG_IMAGE == tag) {
+		const char *src = attributeValue(attributes, "xlink:href");
+		if (src != 0) {
+			myCoverReader.myImage =
+				new ZLFileImage("image/auto", myCoverReader.myPathPrefix + src, 0);
+			interrupt();
+		}
 	}
 }
 
