@@ -42,6 +42,8 @@ protected:
 
 public:
 	void showBook(shared_ptr<Book>);
+	bool onStylusRelease(int x, int y);
+	bool onStylusMovePressed(int x, int y);
 
 private:
 	ZLColor backgroundColor() const;
